@@ -144,6 +144,14 @@ calcTheta <- function(V, sigma) {
     return(object)
 }
 
+#' @export
+`sigma<-.glm` <- function(object, value) {
+
+    if(is.null(value)) return(object)
+
+    stop("sigma is not applicable for this model.")
+}
+
 #' @export
 `sigma<-.lm` <- function(object, value) {
 
